==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24TabbedPaneScrollLayout.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$TabbedPaneScrollLayout

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b290541d8f1a636f javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout
// @dep_class 6aff805229f02fd3 javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout

#include "javax/swing/plaf/basic/BasicTabbedPaneUI__24TabbedPaneLayout.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$calculateTabRects$4ba3488ba053c4ab(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
extern jint _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredTabAreaHeight$7339174c940d3c91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);
extern jint _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredTabAreaWidth$bd440d8044c81d05(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$calculateTabRects$4ba3488ba053c4ab;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredTabAreaHeight$7339174c940d3c91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredTabAreaWidth$bd440d8044c81d05;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods {
	void	(*calculateTabRects$4ba3488ba053c4ab)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *);
	jint	(*preferredTabAreaHeight$7339174c940d3c91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);
	jint	(*preferredTabAreaWidth$bd440d8044c81d05)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24TabbedPaneScrollLayout.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$TabbedPaneScrollLayout

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7355d44b786a29cd javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout
// @dep_class 4181c3818dfb2d72 javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout

#include "javax/swing/plaf/basic/BasicTabbedPaneUI__24TabbedPaneLayout.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$calculateTabRects$4ba3488ba053c4ab(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredTabAreaHeight$7339174c940d3c91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method$preferredTabAreaWidth$bd440d8044c81d05(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$calculateTabRects$4ba3488ba053c4ab;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredTabAreaHeight$7339174c940d3c91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$method_info$preferredTabAreaWidth$bd440d8044c81d05;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods {
	void	(*calculateTabRects$4ba3488ba053c4ab)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	jint	(*preferredTabAreaHeight$7339174c940d3c91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;
	jint	(*preferredTabAreaWidth$bd440d8044c81d05)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneLayout;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabbedPaneScrollLayout_H_ */
